You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2018/07/18 12:39:55 UTC

[camel] branch master updated: CAMEL-12661: Spring Boot auto configuration - NestedConfigurationProperty should only be for known Camel types

This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel.git


The following commit(s) were added to refs/heads/master by this push:
     new d7be618  CAMEL-12661: Spring Boot auto configuration - NestedConfigurationProperty should only be for known Camel types
d7be618 is described below

commit d7be61880a2bfc0fde779616aba5298ed8eb7956
Author: Claus Ibsen <cl...@gmail.com>
AuthorDate: Wed Jul 18 14:39:16 2018 +0200

    CAMEL-12661: Spring Boot auto configuration - NestedConfigurationProperty should only be for known Camel types
---
 .../src/main/docs/as2-component.adoc               |  3 +-
 .../camel-avro/src/main/docs/avro-component.adoc   |  8 +---
 .../camel-avro/src/main/docs/avro-dataformat.adoc  |  8 +---
 .../camel-aws/src/main/docs/aws-ec2-component.adoc |  5 +--
 .../camel-aws/src/main/docs/aws-s3-component.adoc  |  3 +-
 .../camel-aws/src/main/docs/aws-swf-component.adoc | 35 +++--------------
 .../camel-cache/src/main/docs/cache-component.adoc |  9 ++++-
 .../src/main/docs/consul-component.adoc            |  3 +-
 .../src/main/docs/fhir-component.adoc              | 13 +------
 .../src/main/docs/lucene-component.adoc            |  3 +-
 .../src/main/docs/nagios-component.adoc            |  9 +----
 .../camel-netty/src/main/docs/netty-component.adoc |  9 +----
 .../src/main/docs/netty4-component.adoc            |  8 +---
 .../src/main/docs/olingo2-component.adoc           | 11 +++++-
 .../src/main/docs/olingo4-component.adoc           | 11 +++++-
 .../src/main/docs/salesforce-component.adoc        | 13 ++-----
 .../src/main/docs/servicenow-component.adoc        | 44 ++--------------------
 .../as2/springboot/AS2ComponentConfiguration.java  |  2 -
 .../springboot/AvroComponentConfiguration.java     |  2 -
 .../ec2/springboot/EC2ComponentConfiguration.java  |  2 -
 .../s3/springboot/S3ComponentConfiguration.java    |  2 -
 .../swf/springboot/SWFComponentConfiguration.java  |  6 ---
 .../springboot/CacheComponentConfiguration.java    |  1 -
 .../springboot/ConsulComponentConfiguration.java   |  1 -
 .../springboot/FhirComponentConfiguration.java     |  2 -
 .../springboot/LuceneComponentConfiguration.java   |  2 -
 .../springboot/NagiosComponentConfiguration.java   |  2 -
 .../springboot/NettyComponentConfiguration.java    |  1 -
 .../springboot/NettyComponentConfiguration.java    |  1 -
 .../springboot/Olingo2ComponentConfiguration.java  |  3 --
 .../springboot/Olingo4ComponentConfiguration.java  |  3 --
 .../SalesforceComponentConfiguration.java          |  1 -
 .../ServiceNowComponentConfiguration.java          |  3 --
 .../packaging/SpringBootAutoConfigurationMojo.java |  9 ++---
 34 files changed, 67 insertions(+), 171 deletions(-)

diff --git a/components/camel-as2/camel-as2-component/src/main/docs/as2-component.adoc b/components/camel-as2/camel-as2-component/src/main/docs/as2-component.adoc
index dab47aa..09cec1b 100644
--- a/components/camel-as2/camel-as2-component/src/main/docs/as2-component.adoc
+++ b/components/camel-as2/camel-as2-component/src/main/docs/as2-component.adoc
@@ -87,7 +87,7 @@ with the following path and query parameters:
 === Spring Boot Auto-Configuration
 
 
-The component supports 24 options, which are listed below.
+The component supports 25 options, which are listed below.
 
 
 
@@ -113,6 +113,7 @@ The component supports 24 options, which are listed below.
             - the FQDN of client. |  | String
 | *camel.component.as2.configuration.disposition-notification-to* |  |  | String
 | *camel.component.as2.configuration.edi-message-transfer-encoding* |  |  | String
+| *camel.component.as2.configuration.edi-message-type* |  |  | ContentType
 | *camel.component.as2.configuration.from* |  |  | String
 | *camel.component.as2.configuration.method-name* | What sub operation to use for the selected operation
  
diff --git a/components/camel-avro/src/main/docs/avro-component.adoc b/components/camel-avro/src/main/docs/avro-component.adoc
index 4cbd951..3443db0 100644
--- a/components/camel-avro/src/main/docs/avro-component.adoc
+++ b/components/camel-avro/src/main/docs/avro-component.adoc
@@ -233,7 +233,7 @@ with the following path and query parameters:
 === Spring Boot Auto-Configuration
 
 
-The component supports 19 options, which are listed below.
+The component supports 15 options, which are listed below.
 
 
 
@@ -243,13 +243,9 @@ The component supports 19 options, which are listed below.
 | *camel.component.avro.configuration.host* | Hostname to use |  | String
 | *camel.component.avro.configuration.message-name* | The name of the message to send. |  | String
 | *camel.component.avro.configuration.port* | Port number to use |  | Integer
+| *camel.component.avro.configuration.protocol* | Avro protocol to use |  | Protocol
 | *camel.component.avro.configuration.protocol-class-name* | Avro protocol to use defined by the FQN class name |  | String
 | *camel.component.avro.configuration.protocol-location* | Avro protocol location |  | String
-| *camel.component.avro.configuration.protocol.json-props* |  |  | Map
-| *camel.component.avro.configuration.protocol.messages* |  |  | Map
-| *camel.component.avro.configuration.protocol.object-props* |  |  | Map
-| *camel.component.avro.configuration.protocol.props* |  |  | Map
-| *camel.component.avro.configuration.protocol.types* |  |  | Schema>
 | *camel.component.avro.configuration.reflection-protocol* | If protocol object provided is reflection protocol. Should be used
  only with protocol parameter because for protocolClassName protocol
  type will be auto detected | false | Boolean
diff --git a/components/camel-avro/src/main/docs/avro-dataformat.adoc b/components/camel-avro/src/main/docs/avro-dataformat.adoc
index a2d0324..19b1fc2 100644
--- a/components/camel-avro/src/main/docs/avro-dataformat.adoc
+++ b/components/camel-avro/src/main/docs/avro-dataformat.adoc
@@ -145,7 +145,7 @@ The Avro dataformat supports 2 options, which are listed below.
 === Spring Boot Auto-Configuration
 
 
-The component supports 19 options, which are listed below.
+The component supports 15 options, which are listed below.
 
 
 
@@ -155,13 +155,9 @@ The component supports 19 options, which are listed below.
 | *camel.component.avro.configuration.host* | Hostname to use |  | String
 | *camel.component.avro.configuration.message-name* | The name of the message to send. |  | String
 | *camel.component.avro.configuration.port* | Port number to use |  | Integer
+| *camel.component.avro.configuration.protocol* | Avro protocol to use |  | Protocol
 | *camel.component.avro.configuration.protocol-class-name* | Avro protocol to use defined by the FQN class name |  | String
 | *camel.component.avro.configuration.protocol-location* | Avro protocol location |  | String
-| *camel.component.avro.configuration.protocol.json-props* |  |  | Map
-| *camel.component.avro.configuration.protocol.messages* |  |  | Map
-| *camel.component.avro.configuration.protocol.object-props* |  |  | Map
-| *camel.component.avro.configuration.protocol.props* |  |  | Map
-| *camel.component.avro.configuration.protocol.types* |  |  | Schema>
 | *camel.component.avro.configuration.reflection-protocol* | If protocol object provided is reflection protocol. Should be used
  only with protocol parameter because for protocolClassName protocol
  type will be auto detected | false | Boolean
diff --git a/components/camel-aws/src/main/docs/aws-ec2-component.adoc b/components/camel-aws/src/main/docs/aws-ec2-component.adoc
index ce5cb32..a54b9da 100644
--- a/components/camel-aws/src/main/docs/aws-ec2-component.adoc
+++ b/components/camel-aws/src/main/docs/aws-ec2-component.adoc
@@ -83,7 +83,7 @@ with the following path and query parameters:
 === Spring Boot Auto-Configuration
 
 
-The component supports 13 options, which are listed below.
+The component supports 12 options, which are listed below.
 
 
 
@@ -92,8 +92,7 @@ The component supports 13 options, which are listed below.
 | Name | Description | Default | Type
 | *camel.component.aws-ec2.access-key* | Amazon AWS Access Key |  | String
 | *camel.component.aws-ec2.configuration.access-key* | Amazon AWS Access Key |  | String
-| *camel.component.aws-ec2.configuration.amazon-ec2-client.signer-region-override* |  |  | String
-| *camel.component.aws-ec2.configuration.amazon-ec2-client.time-offset* |  |  | Integer
+| *camel.component.aws-ec2.configuration.amazon-ec2-client* | To use a existing configured AmazonEC2Client as client |  | AmazonEC2Client
 | *camel.component.aws-ec2.configuration.operation* | The operation to perform. It can be createAndRunInstances,
  startInstances, stopInstances, terminateInstances, describeInstances,
  describeInstancesStatus, rebootInstances, monitorInstances,
diff --git a/components/camel-aws/src/main/docs/aws-s3-component.adoc b/components/camel-aws/src/main/docs/aws-s3-component.adoc
index 51cf8ae..e5dc2d2 100644
--- a/components/camel-aws/src/main/docs/aws-s3-component.adoc
+++ b/components/camel-aws/src/main/docs/aws-s3-component.adoc
@@ -175,7 +175,8 @@ The component supports 34 options, which are listed below.
  headers, or only the {@link S3Constants#KEY} header. | true | Boolean
 | *camel.component.aws-s3.configuration.delete-after-write* | Delete file object after the S3 file has been uploaded | false | Boolean
 | *camel.component.aws-s3.configuration.dualstack-enabled* | Define if Dualstack enabled is true or false | false | Boolean
-| *camel.component.aws-s3.configuration.encryption-materials.materials-description* |  |  | Map
+| *camel.component.aws-s3.configuration.encryption-materials* | The encryption materials to use in case of Symmetric/Asymmetric
+ client usage |  | EncryptionMaterials
 | *camel.component.aws-s3.configuration.file-name* | To get the object from the bucket with the given file name |  | String
 | *camel.component.aws-s3.configuration.force-global-bucket-access-enabled* | Define if Force Global Bucket Access enabled is true or false | false | Boolean
 | *camel.component.aws-s3.configuration.include-body* | If it is true, the exchange body will be set to a stream to the
diff --git a/components/camel-aws/src/main/docs/aws-swf-component.adoc b/components/camel-aws/src/main/docs/aws-swf-component.adoc
index 11118e8..3c8b273 100644
--- a/components/camel-aws/src/main/docs/aws-swf-component.adoc
+++ b/components/camel-aws/src/main/docs/aws-swf-component.adoc
@@ -105,7 +105,7 @@ with the following path and query parameters:
 === Spring Boot Auto-Configuration
 
 
-The component supports 55 options, which are listed below.
+The component supports 32 options, which are listed below.
 
 
 
@@ -115,28 +115,11 @@ The component supports 55 options, which are listed below.
 | *camel.component.aws-swf.access-key* | Amazon AWS Access Key. |  | String
 | *camel.component.aws-swf.configuration.access-key* | Amazon AWS Access Key. |  | String
 | *camel.component.aws-swf.configuration.activity-list* | The list name to consume activities from. |  | String
-| *camel.component.aws-swf.configuration.activity-scheduling-options.heartbeat-timeout-seconds* |  |  | Long
-| *camel.component.aws-swf.configuration.activity-scheduling-options.schedule-to-close-timeout-seconds* |  |  | Long
-| *camel.component.aws-swf.configuration.activity-scheduling-options.schedule-to-start-timeout-seconds* |  |  | Long
-| *camel.component.aws-swf.configuration.activity-scheduling-options.start-to-close-timeout-seconds* |  |  | Long
-| *camel.component.aws-swf.configuration.activity-scheduling-options.task-list* |  |  | String
-| *camel.component.aws-swf.configuration.activity-scheduling-options.task-priority* |  |  | Integer
+| *camel.component.aws-swf.configuration.activity-scheduling-options* | Activity scheduling options |  | ActivityScheduling Options
 | *camel.component.aws-swf.configuration.activity-thread-pool-size* | Maximum number of threads in work pool for activity. | 100 | Integer
-| *camel.component.aws-swf.configuration.activity-type-execution-options.do-not-retry-task-failed* |  |  | Boolean
-| *camel.component.aws-swf.configuration.activity-type-execution-options.manual-activity-completion* |  |  | Boolean
-| *camel.component.aws-swf.configuration.activity-type-execution-options.respond-task-completed-backoff-coefficient* |  |  | Double
-| *camel.component.aws-swf.configuration.activity-type-execution-options.respond-task-completed-maximum-retries* |  |  | Integer
-| *camel.component.aws-swf.configuration.activity-type-execution-options.respond-task-completed-retry-initial-interval* |  |  | Long
-| *camel.component.aws-swf.configuration.activity-type-execution-options.respond-task-completed-retry-maximum-interval* |  |  | Long
-| *camel.component.aws-swf.configuration.activity-type-registration-options.default-task-heartbeat-timeout-seconds* |  |  | Long
-| *camel.component.aws-swf.configuration.activity-type-registration-options.default-task-list* |  |  | String
-| *camel.component.aws-swf.configuration.activity-type-registration-options.default-task-priority* |  |  | Integer
-| *camel.component.aws-swf.configuration.activity-type-registration-options.default-task-schedule-to-close-timeout-seconds* |  |  | Long
-| *camel.component.aws-swf.configuration.activity-type-registration-options.default-task-schedule-to-start-timeout-seconds* |  |  | Long
-| *camel.component.aws-swf.configuration.activity-type-registration-options.default-task-start-to-close-timeout-seconds* |  |  | Long
-| *camel.component.aws-swf.configuration.activity-type-registration-options.description* |  |  | String
-| *camel.component.aws-swf.configuration.amazon-s-w-client.signer-region-override* |  |  | String
-| *camel.component.aws-swf.configuration.amazon-s-w-client.time-offset* |  |  | Integer
+| *camel.component.aws-swf.configuration.activity-type-execution-options* | Activity execution options |  | ActivityTypeExecution Options
+| *camel.component.aws-swf.configuration.activity-type-registration-options* | Activity registration options |  | ActivityType RegistrationOptions
+| *camel.component.aws-swf.configuration.amazon-s-w-client* | To use the given AmazonSimpleWorkflowClient as client |  | AmazonSimpleWorkflow Client
 | *camel.component.aws-swf.configuration.child-policy* | The policy to use on child workflows when terminating a workflow. |  | String
 | *camel.component.aws-swf.configuration.client-configuration-parameters* | To configure the ClientConfiguration using the key/values from the
  Map. |  | Map
@@ -163,13 +146,7 @@ The component supports 55 options, which are listed below.
 | *camel.component.aws-swf.configuration.type* | Activity or workflow |  | String
 | *camel.component.aws-swf.configuration.version* | The workflow or activity event version to use. |  | String
 | *camel.component.aws-swf.configuration.workflow-list* | The list name to consume workflows from. |  | String
-| *camel.component.aws-swf.configuration.workflow-type-registration-options.default-child-policy* |  |  | ChildPolicy
-| *camel.component.aws-swf.configuration.workflow-type-registration-options.default-execution-start-to-close-timeout-seconds* |  |  | Long
-| *camel.component.aws-swf.configuration.workflow-type-registration-options.default-lambda-role* |  |  | String
-| *camel.component.aws-swf.configuration.workflow-type-registration-options.default-task-list* |  |  | String
-| *camel.component.aws-swf.configuration.workflow-type-registration-options.default-task-priority* |  |  | Integer
-| *camel.component.aws-swf.configuration.workflow-type-registration-options.default-task-start-to-close-timeout-seconds* |  |  | Long
-| *camel.component.aws-swf.configuration.workflow-type-registration-options.description* |  |  | String
+| *camel.component.aws-swf.configuration.workflow-type-registration-options* | Workflow registration options |  | WorkflowType RegistrationOptions
 | *camel.component.aws-swf.enabled* | Enable aws-swf component | true | Boolean
 | *camel.component.aws-swf.region* | Amazon AWS Region. |  | String
 | *camel.component.aws-swf.resolve-property-placeholders* | Whether the component should resolve property placeholders on itself when
diff --git a/components/camel-cache/src/main/docs/cache-component.adoc b/components/camel-cache/src/main/docs/cache-component.adoc
index e2adbac..8e33ae9 100644
--- a/components/camel-cache/src/main/docs/cache-component.adoc
+++ b/components/camel-cache/src/main/docs/cache-component.adoc
@@ -114,7 +114,7 @@ with the following path and query parameters:
 === Spring Boot Auto-Configuration
 
 
-The component supports 16 options, which are listed below.
+The component supports 17 options, which are listed below.
 
 
 
@@ -137,6 +137,13 @@ The component supports 16 options, which are listed below.
 | *camel.component.cache.configuration.event-listener-registry.event-listeners* |  |  | List
 | *camel.component.cache.configuration.max-elements-in-memory* | The number of elements that may be stored in the defined cache in
  memory. | 1000 | Integer
+| *camel.component.cache.configuration.memory-store-eviction-policy* | Which eviction strategy to use when maximum number of elements in
+ memory is reached. The strategy defines which elements to be removed.
+ <ul>
+ <li>LRU - Lest Recently Used</li>
+ <li>LFU - Lest Frequently Used</li>
+ <li>FIFO - First In First Out</li>
+ </ul> |  | MemoryStoreEviction Policy
 | *camel.component.cache.configuration.object-cache* | Whether to turn on allowing to store non serializable objects in the
  cache. If this option is enabled then overflow to disk cannot be
  enabled as well. | false | Boolean
diff --git a/components/camel-consul/src/main/docs/consul-component.adoc b/components/camel-consul/src/main/docs/consul-component.adoc
index 44d72e1..5dcb5a2 100644
--- a/components/camel-consul/src/main/docs/consul-component.adoc
+++ b/components/camel-consul/src/main/docs/consul-component.adoc
@@ -95,7 +95,7 @@ with the following path and query parameters:
 === Spring Boot Auto-Configuration
 
 
-The component supports 102 options, which are listed below.
+The component supports 103 options, which are listed below.
 
 
 
@@ -134,6 +134,7 @@ The component supports 102 options, which are listed below.
 | *camel.component.consul.configuration.block-seconds* | The second to wait for a watch event, default 10 seconds |  | Integer
 | *camel.component.consul.configuration.connect-timeout-millis* | Connect timeout for OkHttpClient |  | Long
 | *camel.component.consul.configuration.consistency-mode* | The consistencyMode used for queries, default ConsistencyMode.DEFAULT |  | ConsistencyMode
+| *camel.component.consul.configuration.consul-client* | Reference to a `com.orbitz.consul.Consul` in the registry. |  | Consul
 | *camel.component.consul.configuration.datacenter* | The data center |  | String
 | *camel.component.consul.configuration.dc* | The data center
  
diff --git a/components/camel-fhir/camel-fhir-component/src/main/docs/fhir-component.adoc b/components/camel-fhir/camel-fhir-component/src/main/docs/fhir-component.adoc
index cfdb7f7..3a88c6c 100644
--- a/components/camel-fhir/camel-fhir-component/src/main/docs/fhir-component.adoc
+++ b/components/camel-fhir/camel-fhir-component/src/main/docs/fhir-component.adoc
@@ -123,7 +123,7 @@ with the following path and query parameters:
 === Spring Boot Auto-Configuration
 
 
-The component supports 32 options, which are listed below.
+The component supports 23 options, which are listed below.
 
 
 
@@ -137,16 +137,7 @@ The component supports 32 options, which are listed below.
 | *camel.component.fhir.configuration.compress* |  | false | Boolean
 | *camel.component.fhir.configuration.connection-timeout* |  | 10000 | Integer
 | *camel.component.fhir.configuration.defer-model-scanning* |  | false | Boolean
-| *camel.component.fhir.configuration.fhir-context.add-profile-tag-when-encoding* |  |  | AddProfileTagEnum
-| *camel.component.fhir.configuration.fhir-context.element-definitions* |  |  | BaseRuntimeElementDefinition<?>>
-| *camel.component.fhir.configuration.fhir-context.localizer* |  |  | HapiLocalizer
-| *camel.component.fhir.configuration.fhir-context.narrative-generator* |  |  | INarrativeGenerator
-| *camel.component.fhir.configuration.fhir-context.parser-options* |  |  | ParserOptions
-| *camel.component.fhir.configuration.fhir-context.performance-options* |  |  | Set
-| *camel.component.fhir.configuration.fhir-context.resource-definitions-with-explicit-id* |  |  | RuntimeResourceDefinition>
-| *camel.component.fhir.configuration.fhir-context.resource-names* |  |  | Set
-| *camel.component.fhir.configuration.fhir-context.restful-client-factory* |  |  | IRestfulClientFactory
-| *camel.component.fhir.configuration.fhir-context.validation-support* |  |  | IContextValidation Support<?,?,?,?,?,?>
+| *camel.component.fhir.configuration.fhir-context* |  |  | FhirContext
 | *camel.component.fhir.configuration.force-conformance-check* |  | false | Boolean
 | *camel.component.fhir.configuration.log* |  | false | Boolean
 | *camel.component.fhir.configuration.method-name* | What sub operation to use for the selected operation |  | String
diff --git a/components/camel-lucene/src/main/docs/lucene-component.adoc b/components/camel-lucene/src/main/docs/lucene-component.adoc
index 9685144..bd61e24 100644
--- a/components/camel-lucene/src/main/docs/lucene-component.adoc
+++ b/components/camel-lucene/src/main/docs/lucene-component.adoc
@@ -107,7 +107,7 @@ with the following path and query parameters:
 === Spring Boot Auto-Configuration
 
 
-The component supports 10 options, which are listed below.
+The component supports 11 options, which are listed below.
 
 
 
@@ -123,6 +123,7 @@ The component supports 10 options, which are listed below.
 | *camel.component.lucene.config.host* | The URL to the lucene server |  | String
 | *camel.component.lucene.config.index-directory* | A file system directory in which index files are created upon
  analysis of the document by the specified analyzer |  | File
+| *camel.component.lucene.config.lucene-version* |  |  | Version
 | *camel.component.lucene.config.max-hits* | An integer value that limits the result set of the search operation |  | Integer
 | *camel.component.lucene.config.operation* | Operation to do such as insert or query. |  | LuceneOperation
 | *camel.component.lucene.config.source-directory* | An optional directory containing files to be used to be analyzed and
diff --git a/components/camel-nagios/src/main/docs/nagios-component.adoc b/components/camel-nagios/src/main/docs/nagios-component.adoc
index 34b5e15..71dafce 100644
--- a/components/camel-nagios/src/main/docs/nagios-component.adoc
+++ b/components/camel-nagios/src/main/docs/nagios-component.adoc
@@ -96,7 +96,7 @@ with the following path and query parameters:
 === Spring Boot Auto-Configuration
 
 
-The component supports 15 options, which are listed below.
+The component supports 10 options, which are listed below.
 
 
 
@@ -109,12 +109,7 @@ The component supports 15 options, which are listed below.
  
  @deprecated use the {@link #encryption} query parameter instead. |  | NagiosEncryptionMethod
 | *camel.component.nagios.configuration.host* | This is the address of the Nagios host where checks should be send. |  | String
-| *camel.component.nagios.configuration.nagios-settings.connect-timeout* |  |  | Integer
-| *camel.component.nagios.configuration.nagios-settings.encryptor* |  |  | Encryptor
-| *camel.component.nagios.configuration.nagios-settings.nagios-host* |  |  | String
-| *camel.component.nagios.configuration.nagios-settings.password* |  |  | String
-| *camel.component.nagios.configuration.nagios-settings.port* |  |  | Integer
-| *camel.component.nagios.configuration.nagios-settings.timeout* |  |  | Integer
+| *camel.component.nagios.configuration.nagios-settings* |  |  | NagiosSettings
 | *camel.component.nagios.configuration.password* | Password to be authenticated when sending checks to Nagios. |  | String
 | *camel.component.nagios.configuration.port* | The port number of the host. |  | Integer
 | *camel.component.nagios.configuration.timeout* | Sending timeout in millis. | 5000 | Integer
diff --git a/components/camel-netty/src/main/docs/netty-component.adoc b/components/camel-netty/src/main/docs/netty-component.adoc
index 487beb3..e565594 100644
--- a/components/camel-netty/src/main/docs/netty-component.adoc
+++ b/components/camel-netty/src/main/docs/netty-component.adoc
@@ -178,7 +178,7 @@ with the following path and query parameters:
 === Spring Boot Auto-Configuration
 
 
-The component supports 88 options, which are listed below.
+The component supports 83 options, which are listed below.
 
 
 
@@ -324,12 +324,7 @@ The component supports 88 options, which are listed below.
 | *camel.component.netty.configuration.ssl-context-parameters.server-parameters* |  |  | SSLContextServer Parameters
 | *camel.component.netty.configuration.ssl-context-parameters.session-timeout* |  |  | String
 | *camel.component.netty.configuration.ssl-context-parameters.trust-managers* |  |  | TrustManagersParameters
-| *camel.component.netty.configuration.ssl-handler.close-on-s-s-l-exception* |  |  | Boolean
-| *camel.component.netty.configuration.ssl-handler.enable-renegotiation* |  |  | Boolean
-| *camel.component.netty.configuration.ssl-handler.issue-handshake* |  |  | Boolean
-| *camel.component.netty.configuration.ssl-handler.max-cumulation-buffer-capacity* |  |  | Integer
-| *camel.component.netty.configuration.ssl-handler.max-cumulation-buffer-components* |  |  | Integer
-| *camel.component.netty.configuration.ssl-handler.unfold* |  |  | Boolean
+| *camel.component.netty.configuration.ssl-handler* | Reference to a class that could be used to return an SSL Handler |  | SslHandler
 | *camel.component.netty.configuration.sync* | Setting to set endpoint as one-way or request-response | true | Boolean
 | *camel.component.netty.configuration.tcp-no-delay* | Setting to improve TCP protocol performance | true | Boolean
 | *camel.component.netty.configuration.textline* | Only used for TCP. If no codec is specified, you can use this flag to
diff --git a/components/camel-netty4/src/main/docs/netty4-component.adoc b/components/camel-netty4/src/main/docs/netty4-component.adoc
index ef1cb32..f7ae9ea 100644
--- a/components/camel-netty4/src/main/docs/netty4-component.adoc
+++ b/components/camel-netty4/src/main/docs/netty4-component.adoc
@@ -171,7 +171,7 @@ with the following path and query parameters:
 === Spring Boot Auto-Configuration
 
 
-The component supports 94 options, which are listed below.
+The component supports 90 options, which are listed below.
 
 
 
@@ -353,11 +353,7 @@ The component supports 94 options, which are listed below.
 | *camel.component.netty4.configuration.ssl-context-parameters.server-parameters* |  |  | SSLContextServer Parameters
 | *camel.component.netty4.configuration.ssl-context-parameters.session-timeout* |  |  | String
 | *camel.component.netty4.configuration.ssl-context-parameters.trust-managers* |  |  | TrustManagersParameters
-| *camel.component.netty4.configuration.ssl-handler.close-notify-flush-timeout-millis* |  |  | Long
-| *camel.component.netty4.configuration.ssl-handler.close-notify-read-timeout-millis* |  |  | Long
-| *camel.component.netty4.configuration.ssl-handler.close-notify-timeout-millis* |  |  | Long
-| *camel.component.netty4.configuration.ssl-handler.handshake-timeout-millis* |  |  | Long
-| *camel.component.netty4.configuration.ssl-handler.single-decode* |  |  | Boolean
+| *camel.component.netty4.configuration.ssl-handler* | Reference to a class that could be used to return an SSL Handler |  | SslHandler
 | *camel.component.netty4.configuration.sync* | Setting to set endpoint as one-way or request-response | true | Boolean
 | *camel.component.netty4.configuration.tcp-no-delay* | Setting to improve TCP protocol performance | true | Boolean
 | *camel.component.netty4.configuration.textline* | Only used for TCP. If no codec is specified, you can use this flag to
diff --git a/components/camel-olingo2/camel-olingo2-component/src/main/docs/olingo2-component.adoc b/components/camel-olingo2/camel-olingo2-component/src/main/docs/olingo2-component.adoc
index ee4305d..b5aa90d 100644
--- a/components/camel-olingo2/camel-olingo2-component/src/main/docs/olingo2-component.adoc
+++ b/components/camel-olingo2/camel-olingo2-component/src/main/docs/olingo2-component.adoc
@@ -108,7 +108,7 @@ with the following path and query parameters:
 === Spring Boot Auto-Configuration
 
 
-The component supports 24 options, which are listed below.
+The component supports 27 options, which are listed below.
 
 
 
@@ -120,9 +120,18 @@ The component supports 24 options, which are listed below.
  (30 seconds) | 30000 | Integer
 | *camel.component.olingo2.configuration.content-type* | Content-Type header value can be used to specify JSON or XML message
  format, defaults to application/json;charset=utf-8 | application/json;charset=utf-8 | String
+| *camel.component.olingo2.configuration.http-async-client-builder* | Custom HTTP async client builder for more complex HTTP client
+ configuration, overrides connectionTimeout, socketTimeout, proxy and
+ sslContext. Note that a socketTimeout MUST be specified in the
+ builder, otherwise OData requests could block indefinitely |  | HttpAsyncClientBuilder
+| *camel.component.olingo2.configuration.http-client-builder* | Custom HTTP client builder for more complex HTTP client
+ configuration, overrides connectionTimeout, socketTimeout, proxy and
+ sslContext. Note that a socketTimeout MUST be specified in the
+ builder, otherwise OData requests could block indefinitely |  | HttpClientBuilder
 | *camel.component.olingo2.configuration.http-headers* | Custom HTTP headers to inject into every request, this could include
  OAuth tokens, etc. |  | Map
 | *camel.component.olingo2.configuration.method-name* | What sub operation to use for the selected operation |  | String
+| *camel.component.olingo2.configuration.proxy* | HTTP proxy server configuration |  | HttpHost
 | *camel.component.olingo2.configuration.service-uri* | Target OData service base URI, e.g.
  http://services.odata.org/OData/OData.svc |  | String
 | *camel.component.olingo2.configuration.socket-timeout* | HTTP request timeout in milliseconds, defaults to 30,000 (30 seconds) | 30000 | Integer
diff --git a/components/camel-olingo4/camel-olingo4-component/src/main/docs/olingo4-component.adoc b/components/camel-olingo4/camel-olingo4-component/src/main/docs/olingo4-component.adoc
index 593cdbc..1589556 100644
--- a/components/camel-olingo4/camel-olingo4-component/src/main/docs/olingo4-component.adoc
+++ b/components/camel-olingo4/camel-olingo4-component/src/main/docs/olingo4-component.adoc
@@ -109,7 +109,7 @@ with the following path and query parameters:
 === Spring Boot Auto-Configuration
 
 
-The component supports 24 options, which are listed below.
+The component supports 27 options, which are listed below.
 
 
 
@@ -121,9 +121,18 @@ The component supports 24 options, which are listed below.
  (30 seconds) | 30000 | Integer
 | *camel.component.olingo4.configuration.content-type* | Content-Type header value can be used to specify JSON or XML message
  format, defaults to application/json;charset=utf-8 | application/json;charset=utf-8 | String
+| *camel.component.olingo4.configuration.http-async-client-builder* | Custom HTTP async client builder for more complex HTTP client
+ configuration, overrides connectionTimeout, socketTimeout, proxy and
+ sslContext. Note that a socketTimeout MUST be specified in the
+ builder, otherwise OData requests could block indefinitely |  | HttpAsyncClientBuilder
+| *camel.component.olingo4.configuration.http-client-builder* | Custom HTTP client builder for more complex HTTP client
+ configuration, overrides connectionTimeout, socketTimeout, proxy and
+ sslContext. Note that a socketTimeout MUST be specified in the
+ builder, otherwise OData requests could block indefinitely |  | HttpClientBuilder
 | *camel.component.olingo4.configuration.http-headers* | Custom HTTP headers to inject into every request, this could include
  OAuth tokens, etc. |  | Map
 | *camel.component.olingo4.configuration.method-name* | What sub operation to use for the selected operation |  | String
+| *camel.component.olingo4.configuration.proxy* | HTTP proxy server configuration |  | HttpHost
 | *camel.component.olingo4.configuration.service-uri* | Target OData service base URI, e.g.
  http://services.odata.org/OData/OData.svc |  | String
 | *camel.component.olingo4.configuration.socket-timeout* | HTTP request timeout in milliseconds, defaults to 30,000 (30 seconds) | 30000 | Integer
diff --git a/components/camel-salesforce/camel-salesforce-component/src/main/docs/salesforce-component.adoc b/components/camel-salesforce/camel-salesforce-component/src/main/docs/salesforce-component.adoc
index e4ab543..26611a6 100644
--- a/components/camel-salesforce/camel-salesforce-component/src/main/docs/salesforce-component.adoc
+++ b/components/camel-salesforce/camel-salesforce-component/src/main/docs/salesforce-component.adoc
@@ -756,7 +756,7 @@ with the following path and query parameters:
 === Spring Boot Auto-Configuration
 
 
-The component supports 148 options, which are listed below.
+The component supports 140 options, which are listed below.
 
 
 
@@ -877,15 +877,8 @@ The component supports 148 options, which are listed below.
 | *camel.component.salesforce.config.notify-for-operation-update* | Notify for update operation, defaults to false (API version >= 29.0) |  | Boolean
 | *camel.component.salesforce.config.notify-for-operations* | Notify for operations, options are ALL, CREATE, EXTENDED, UPDATE (API
  version < 29.0) |  | NotifyForOperations Enum
-| *camel.component.salesforce.config.object-mapper.date-format* |  |  | DateFormat
-| *camel.component.salesforce.config.object-mapper.injectable-values* |  |  | InjectableValues
-| *camel.component.salesforce.config.object-mapper.node-factory* |  |  | JsonNodeFactory
-| *camel.component.salesforce.config.object-mapper.property-naming-strategy* |  |  | PropertyNamingStrategy
-| *camel.component.salesforce.config.object-mapper.registered-module-ids* |  |  | Set
-| *camel.component.salesforce.config.object-mapper.serializer-factory* |  |  | SerializerFactory
-| *camel.component.salesforce.config.object-mapper.subtype-resolver* |  |  | SubtypeResolver
-| *camel.component.salesforce.config.object-mapper.type-factory* |  |  | TypeFactory
-| *camel.component.salesforce.config.object-mapper.visibility-checker* |  |  | VisibilityChecker<?>
+| *camel.component.salesforce.config.object-mapper* | Custom Jackson ObjectMapper to use when serializing/deserializing
+ Salesforce objects. |  | ObjectMapper
 | *camel.component.salesforce.config.raw-payload* | Use raw payload {@link String} for request and response (either JSON
  or XML depending on {@code format} ), instead of DTOs, false by
  default | false | Boolean
diff --git a/components/camel-servicenow/camel-servicenow-component/src/main/docs/servicenow-component.adoc b/components/camel-servicenow/camel-servicenow-component/src/main/docs/servicenow-component.adoc
index f9bb974..bc21b29 100644
--- a/components/camel-servicenow/camel-servicenow-component/src/main/docs/servicenow-component.adoc
+++ b/components/camel-servicenow/camel-servicenow-component/src/main/docs/servicenow-component.adoc
@@ -131,7 +131,7 @@ with the following path and query parameters:
 === Spring Boot Auto-Configuration
 
 
-The component supports 106 options, which are listed below.
+The component supports 70 options, which are listed below.
 
 
 
@@ -152,32 +152,7 @@ The component supports 106 options, which are listed below.
 | *camel.component.servicenow.configuration.exclude-reference-link* | True to exclude Table API links for reference fields (default: false) |  | Boolean
 | *camel.component.servicenow.configuration.favorites* | Set this parameter to true to return only scorecards that are
  favorites of the querying user. |  | Boolean
-| *camel.component.servicenow.configuration.http-client-policy.accept* |  |  | String
-| *camel.component.servicenow.configuration.http-client-policy.accept-encoding* |  |  | String
-| *camel.component.servicenow.configuration.http-client-policy.accept-language* |  |  | String
-| *camel.component.servicenow.configuration.http-client-policy.allow-chunking* |  |  | Boolean
-| *camel.component.servicenow.configuration.http-client-policy.async-execute-timeout* |  |  | Long
-| *camel.component.servicenow.configuration.http-client-policy.async-execute-timeout-rejection* |  |  | Boolean
-| *camel.component.servicenow.configuration.http-client-policy.auto-redirect* |  |  | Boolean
-| *camel.component.servicenow.configuration.http-client-policy.browser-type* |  |  | String
-| *camel.component.servicenow.configuration.http-client-policy.cache-control* |  |  | String
-| *camel.component.servicenow.configuration.http-client-policy.chunk-length* |  |  | Integer
-| *camel.component.servicenow.configuration.http-client-policy.chunking-threshold* |  |  | Integer
-| *camel.component.servicenow.configuration.http-client-policy.connection* |  |  | ConnectionType
-| *camel.component.servicenow.configuration.http-client-policy.connection-request-timeout* |  |  | Long
-| *camel.component.servicenow.configuration.http-client-policy.connection-timeout* |  |  | Long
-| *camel.component.servicenow.configuration.http-client-policy.content-type* |  |  | String
-| *camel.component.servicenow.configuration.http-client-policy.cookie* |  |  | String
-| *camel.component.servicenow.configuration.http-client-policy.decoupled-endpoint* |  |  | String
-| *camel.component.servicenow.configuration.http-client-policy.host* |  |  | String
-| *camel.component.servicenow.configuration.http-client-policy.max-retransmits* |  |  | Integer
-| *camel.component.servicenow.configuration.http-client-policy.non-proxy-hosts* |  |  | String
-| *camel.component.servicenow.configuration.http-client-policy.other-attributes* |  |  | Map
-| *camel.component.servicenow.configuration.http-client-policy.proxy-server* |  |  | String
-| *camel.component.servicenow.configuration.http-client-policy.proxy-server-port* |  |  | Integer
-| *camel.component.servicenow.configuration.http-client-policy.proxy-server-type* |  |  | ProxyServerType
-| *camel.component.servicenow.configuration.http-client-policy.receive-timeout* |  |  | Long
-| *camel.component.servicenow.configuration.http-client-policy.referer* |  |  | String
+| *camel.component.servicenow.configuration.http-client-policy* | To configure http-client |  | HTTPClientPolicy
 | *camel.component.servicenow.configuration.include-aggregates* | Set this parameter to true to always return all available aggregates
  for an indicator, including when an aggregate has already been
  applied. If a value is not specified, this parameter defaults to
@@ -198,15 +173,7 @@ The component supports 106 options, which are listed below.
 | *camel.component.servicenow.configuration.input-display-value* | True to set raw value of input fields (default: false) |  | Boolean
 | *camel.component.servicenow.configuration.key* | Set this parameter to true to return only scorecards for key
  indicators. |  | Boolean
-| *camel.component.servicenow.configuration.mapper.date-format* |  |  | DateFormat
-| *camel.component.servicenow.configuration.mapper.injectable-values* |  |  | InjectableValues
-| *camel.component.servicenow.configuration.mapper.node-factory* |  |  | JsonNodeFactory
-| *camel.component.servicenow.configuration.mapper.property-naming-strategy* |  |  | PropertyNamingStrategy
-| *camel.component.servicenow.configuration.mapper.registered-module-ids* |  |  | Set
-| *camel.component.servicenow.configuration.mapper.serializer-factory* |  |  | SerializerFactory
-| *camel.component.servicenow.configuration.mapper.subtype-resolver* |  |  | SubtypeResolver
-| *camel.component.servicenow.configuration.mapper.type-factory* |  |  | TypeFactory
-| *camel.component.servicenow.configuration.mapper.visibility-checker* |  |  | VisibilityChecker<?>
+| *camel.component.servicenow.configuration.mapper* | Sets Jackson's ObjectMapper to use for request/reply |  | ObjectMapper
 | *camel.component.servicenow.configuration.models* |  |  | Map
 | *camel.component.servicenow.configuration.oauth-client-id* | OAuth2 ClientID |  | String
 | *camel.component.servicenow.configuration.oauth-client-secret* | OAuth2 ClientSecret |  | String
@@ -214,10 +181,7 @@ The component supports 106 options, which are listed below.
 | *camel.component.servicenow.configuration.password* | ServiceNow account password, MUST be provided |  | String
 | *camel.component.servicenow.configuration.per-page* | Enter the maximum number of scorecards each query can return. By
  default this value is 10, and the maximum is 100. | 10 | Integer
-| *camel.component.servicenow.configuration.proxy-authorization-policy.authorization* |  |  | String
-| *camel.component.servicenow.configuration.proxy-authorization-policy.authorization-type* |  |  | String
-| *camel.component.servicenow.configuration.proxy-authorization-policy.password* |  |  | String
-| *camel.component.servicenow.configuration.proxy-authorization-policy.user-name* |  |  | String
+| *camel.component.servicenow.configuration.proxy-authorization-policy* | To configure proxy authentication |  | ProxyAuthorization Policy
 | *camel.component.servicenow.configuration.proxy-host* | The proxy host name |  | String
 | *camel.component.servicenow.configuration.proxy-password* | Password for proxy authentication |  | String
 | *camel.component.servicenow.configuration.proxy-port* | The proxy port number |  | Integer
diff --git a/platforms/spring-boot/components-starter/camel-as2-starter/src/main/java/org/apache/camel/component/as2/springboot/AS2ComponentConfiguration.java b/platforms/spring-boot/components-starter/camel-as2-starter/src/main/java/org/apache/camel/component/as2/springboot/AS2ComponentConfiguration.java
index 17bdc40..d08014f 100644
--- a/platforms/spring-boot/components-starter/camel-as2-starter/src/main/java/org/apache/camel/component/as2/springboot/AS2ComponentConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-as2-starter/src/main/java/org/apache/camel/component/as2/springboot/AS2ComponentConfiguration.java
@@ -24,7 +24,6 @@ import org.apache.camel.component.as2.internal.AS2ApiName;
 import org.apache.camel.spring.boot.ComponentConfigurationPropertiesCommon;
 import org.apache.http.entity.ContentType;
 import org.springframework.boot.context.properties.ConfigurationProperties;
-import org.springframework.boot.context.properties.NestedConfigurationProperty;
 
 /**
  * Component used for transferring data secure and reliable over the internet
@@ -139,7 +138,6 @@ public class AS2ComponentConfiguration
         private String clientFqdn;
         private Integer serverPortNumber;
         private String requestUri;
-        @NestedConfigurationProperty
         private ContentType ediMessageType;
         private String ediMessageTransferEncoding;
         private AS2MessageStructure as2MessageStructure;
diff --git a/platforms/spring-boot/components-starter/camel-avro-starter/src/main/java/org/apache/camel/component/avro/springboot/AvroComponentConfiguration.java b/platforms/spring-boot/components-starter/camel-avro-starter/src/main/java/org/apache/camel/component/avro/springboot/AvroComponentConfiguration.java
index 04d6b27..70ef9a0 100644
--- a/platforms/spring-boot/components-starter/camel-avro-starter/src/main/java/org/apache/camel/component/avro/springboot/AvroComponentConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-avro-starter/src/main/java/org/apache/camel/component/avro/springboot/AvroComponentConfiguration.java
@@ -21,7 +21,6 @@ import org.apache.avro.Protocol;
 import org.apache.camel.component.avro.AvroTransport;
 import org.apache.camel.spring.boot.ComponentConfigurationPropertiesCommon;
 import org.springframework.boot.context.properties.ConfigurationProperties;
-import org.springframework.boot.context.properties.NestedConfigurationProperty;
 
 /**
  * Working with Apache Avro for data serialization.
@@ -81,7 +80,6 @@ public class AvroComponentConfiguration
         /**
          * Avro protocol to use
          */
-        @NestedConfigurationProperty
         private Protocol protocol;
         private AvroTransport transport;
         /**
diff --git a/platforms/spring-boot/components-starter/camel-aws-starter/src/main/java/org/apache/camel/component/aws/ec2/springboot/EC2ComponentConfiguration.java b/platforms/spring-boot/components-starter/camel-aws-starter/src/main/java/org/apache/camel/component/aws/ec2/springboot/EC2ComponentConfiguration.java
index c2a79f1..a58a8d3 100644
--- a/platforms/spring-boot/components-starter/camel-aws-starter/src/main/java/org/apache/camel/component/aws/ec2/springboot/EC2ComponentConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-aws-starter/src/main/java/org/apache/camel/component/aws/ec2/springboot/EC2ComponentConfiguration.java
@@ -21,7 +21,6 @@ import com.amazonaws.services.ec2.AmazonEC2Client;
 import org.apache.camel.component.aws.ec2.EC2Operations;
 import org.apache.camel.spring.boot.ComponentConfigurationPropertiesCommon;
 import org.springframework.boot.context.properties.ConfigurationProperties;
-import org.springframework.boot.context.properties.NestedConfigurationProperty;
 
 /**
  * The aws-ec2 is used for managing Amazon EC2 instances.
@@ -109,7 +108,6 @@ public class EC2ComponentConfiguration
         /**
          * To use a existing configured AmazonEC2Client as client
          */
-        @NestedConfigurationProperty
         private AmazonEC2Client amazonEc2Client;
         /**
          * Amazon AWS Access Key
diff --git a/platforms/spring-boot/components-starter/camel-aws-starter/src/main/java/org/apache/camel/component/aws/s3/springboot/S3ComponentConfiguration.java b/platforms/spring-boot/components-starter/camel-aws-starter/src/main/java/org/apache/camel/component/aws/s3/springboot/S3ComponentConfiguration.java
index e5b5e87..7b6c835 100644
--- a/platforms/spring-boot/components-starter/camel-aws-starter/src/main/java/org/apache/camel/component/aws/s3/springboot/S3ComponentConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-aws-starter/src/main/java/org/apache/camel/component/aws/s3/springboot/S3ComponentConfiguration.java
@@ -22,7 +22,6 @@ import com.amazonaws.services.s3.model.EncryptionMaterials;
 import org.apache.camel.component.aws.s3.S3Operations;
 import org.apache.camel.spring.boot.ComponentConfigurationPropertiesCommon;
 import org.springframework.boot.context.properties.ConfigurationProperties;
-import org.springframework.boot.context.properties.NestedConfigurationProperty;
 
 /**
  * The aws-s3 component is used for storing and retrieving objecct from Amazon
@@ -221,7 +220,6 @@ public class S3ComponentConfiguration
          * The encryption materials to use in case of Symmetric/Asymmetric
          * client usage
          */
-        @NestedConfigurationProperty
         private EncryptionMaterials encryptionMaterials;
         /**
          * Define if encryption must be used or not
diff --git a/platforms/spring-boot/components-starter/camel-aws-starter/src/main/java/org/apache/camel/component/aws/swf/springboot/SWFComponentConfiguration.java b/platforms/spring-boot/components-starter/camel-aws-starter/src/main/java/org/apache/camel/component/aws/swf/springboot/SWFComponentConfiguration.java
index 211ff04..ac5bf09 100644
--- a/platforms/spring-boot/components-starter/camel-aws-starter/src/main/java/org/apache/camel/component/aws/swf/springboot/SWFComponentConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-aws-starter/src/main/java/org/apache/camel/component/aws/swf/springboot/SWFComponentConfiguration.java
@@ -26,7 +26,6 @@ import com.amazonaws.services.simpleworkflow.flow.worker.ActivityTypeExecutionOp
 import com.amazonaws.services.simpleworkflow.flow.worker.ActivityTypeRegistrationOptions;
 import org.apache.camel.spring.boot.ComponentConfigurationPropertiesCommon;
 import org.springframework.boot.context.properties.ConfigurationProperties;
-import org.springframework.boot.context.properties.NestedConfigurationProperty;
 
 /**
  * The aws-swf component is used for managing workflows from Amazon Simple
@@ -161,7 +160,6 @@ public class SWFComponentConfiguration
         /**
          * To use the given AmazonSimpleWorkflowClient as client
          */
-        @NestedConfigurationProperty
         private AmazonSimpleWorkflowClient amazonSWClient;
         /**
          * To configure the StartWorkflowOptions using the key/values from the
@@ -197,12 +195,10 @@ public class SWFComponentConfiguration
         /**
          * Activity execution options
          */
-        @NestedConfigurationProperty
         private ActivityTypeExecutionOptions activityTypeExecutionOptions;
         /**
          * Activity registration options
          */
-        @NestedConfigurationProperty
         private ActivityTypeRegistrationOptions activityTypeRegistrationOptions;
         /**
          * An instance of
@@ -213,12 +209,10 @@ public class SWFComponentConfiguration
         /**
          * Workflow registration options
          */
-        @NestedConfigurationProperty
         private WorkflowTypeRegistrationOptions workflowTypeRegistrationOptions;
         /**
          * Activity scheduling options
          */
-        @NestedConfigurationProperty
         private ActivitySchedulingOptions activitySchedulingOptions;
         /**
          * Maximum number of threads in work pool for activity.
diff --git a/platforms/spring-boot/components-starter/camel-cache-starter/src/main/java/org/apache/camel/component/cache/springboot/CacheComponentConfiguration.java b/platforms/spring-boot/components-starter/camel-cache-starter/src/main/java/org/apache/camel/component/cache/springboot/CacheComponentConfiguration.java
index b58f978..b731016 100644
--- a/platforms/spring-boot/components-starter/camel-cache-starter/src/main/java/org/apache/camel/component/cache/springboot/CacheComponentConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-cache-starter/src/main/java/org/apache/camel/component/cache/springboot/CacheComponentConfiguration.java
@@ -118,7 +118,6 @@ public class CacheComponentConfiguration
          * <li>FIFO - First In First Out</li>
          * </ul>
          */
-        @NestedConfigurationProperty
         private MemoryStoreEvictionPolicy memoryStoreEvictionPolicy;
         /**
          * Specifies whether cache may overflow to disk
diff --git a/platforms/spring-boot/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/ConsulComponentConfiguration.java b/platforms/spring-boot/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/ConsulComponentConfiguration.java
index 754f87e..c06791a 100644
--- a/platforms/spring-boot/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/ConsulComponentConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/ConsulComponentConfiguration.java
@@ -180,7 +180,6 @@ public class ConsulComponentConfiguration
         /**
          * Reference to a `com.orbitz.consul.Consul` in the registry.
          */
-        @NestedConfigurationProperty
         private Consul consulClient;
         /**
          * The Consul agent URL
diff --git a/platforms/spring-boot/components-starter/camel-fhir-starter/src/main/java/org/apache/camel/component/fhir/springboot/FhirComponentConfiguration.java b/platforms/spring-boot/components-starter/camel-fhir-starter/src/main/java/org/apache/camel/component/fhir/springboot/FhirComponentConfiguration.java
index 23619e6..0875e18 100644
--- a/platforms/spring-boot/components-starter/camel-fhir-starter/src/main/java/org/apache/camel/component/fhir/springboot/FhirComponentConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-fhir-starter/src/main/java/org/apache/camel/component/fhir/springboot/FhirComponentConfiguration.java
@@ -23,7 +23,6 @@ import ca.uhn.fhir.rest.client.api.IRestfulClientFactory;
 import org.apache.camel.component.fhir.internal.FhirApiName;
 import org.apache.camel.spring.boot.ComponentConfigurationPropertiesCommon;
 import org.springframework.boot.context.properties.ConfigurationProperties;
-import org.springframework.boot.context.properties.NestedConfigurationProperty;
 
 /**
  * Represents a FHIR endpoint.
@@ -82,7 +81,6 @@ public class FhirComponentConfiguration
          * What sub operation to use for the selected operation
          */
         private String methodName;
-        @NestedConfigurationProperty
         private FhirContext fhirContext;
         private Boolean forceConformanceCheck = false;
         private String username;
diff --git a/platforms/spring-boot/components-starter/camel-lucene-starter/src/main/java/org/apache/camel/component/lucene/springboot/LuceneComponentConfiguration.java b/platforms/spring-boot/components-starter/camel-lucene-starter/src/main/java/org/apache/camel/component/lucene/springboot/LuceneComponentConfiguration.java
index 539cf4a..55457ba 100644
--- a/platforms/spring-boot/components-starter/camel-lucene-starter/src/main/java/org/apache/camel/component/lucene/springboot/LuceneComponentConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-lucene-starter/src/main/java/org/apache/camel/component/lucene/springboot/LuceneComponentConfiguration.java
@@ -24,7 +24,6 @@ import org.apache.camel.spring.boot.ComponentConfigurationPropertiesCommon;
 import org.apache.lucene.analysis.Analyzer;
 import org.apache.lucene.util.Version;
 import org.springframework.boot.context.properties.ConfigurationProperties;
-import org.springframework.boot.context.properties.NestedConfigurationProperty;
 
 /**
  * To insert or query from Apache Lucene databases.
@@ -104,7 +103,6 @@ public class LuceneComponentConfiguration
          * An integer value that limits the result set of the search operation
          */
         private Integer maxHits;
-        @NestedConfigurationProperty
         private Version luceneVersion;
 
         public URI getUri() {
diff --git a/platforms/spring-boot/components-starter/camel-nagios-starter/src/main/java/org/apache/camel/component/nagios/springboot/NagiosComponentConfiguration.java b/platforms/spring-boot/components-starter/camel-nagios-starter/src/main/java/org/apache/camel/component/nagios/springboot/NagiosComponentConfiguration.java
index 75b8f2e..027a1ed 100644
--- a/platforms/spring-boot/components-starter/camel-nagios-starter/src/main/java/org/apache/camel/component/nagios/springboot/NagiosComponentConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-nagios-starter/src/main/java/org/apache/camel/component/nagios/springboot/NagiosComponentConfiguration.java
@@ -23,7 +23,6 @@ import org.apache.camel.component.nagios.NagiosEncryptionMethod;
 import org.apache.camel.spring.boot.ComponentConfigurationPropertiesCommon;
 import org.springframework.boot.context.properties.ConfigurationProperties;
 import org.springframework.boot.context.properties.DeprecatedConfigurationProperty;
-import org.springframework.boot.context.properties.NestedConfigurationProperty;
 
 /**
  * To send passive checks to Nagios using JSendNSCA.
@@ -72,7 +71,6 @@ public class NagiosComponentConfiguration
 
     public static class NagiosConfigurationNestedConfiguration {
         public static final Class CAMEL_NESTED_CLASS = org.apache.camel.component.nagios.NagiosConfiguration.class;
-        @NestedConfigurationProperty
         private NagiosSettings nagiosSettings;
         /**
          * This is the address of the Nagios host where checks should be send.
diff --git a/platforms/spring-boot/components-starter/camel-netty-starter/src/main/java/org/apache/camel/component/netty/springboot/NettyComponentConfiguration.java b/platforms/spring-boot/components-starter/camel-netty-starter/src/main/java/org/apache/camel/component/netty/springboot/NettyComponentConfiguration.java
index 8a104c7..6b48b0b 100644
--- a/platforms/spring-boot/components-starter/camel-netty-starter/src/main/java/org/apache/camel/component/netty/springboot/NettyComponentConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-netty-starter/src/main/java/org/apache/camel/component/netty/springboot/NettyComponentConfiguration.java
@@ -375,7 +375,6 @@ public class NettyComponentConfiguration
         /**
          * Reference to a class that could be used to return an SSL Handler
          */
-        @NestedConfigurationProperty
         private SslHandler sslHandler;
         /**
          * To configure security using SSLContextParameters
diff --git a/platforms/spring-boot/components-starter/camel-netty4-starter/src/main/java/org/apache/camel/component/netty4/springboot/NettyComponentConfiguration.java b/platforms/spring-boot/components-starter/camel-netty4-starter/src/main/java/org/apache/camel/component/netty4/springboot/NettyComponentConfiguration.java
index a4bea74..22e3ff1 100644
--- a/platforms/spring-boot/components-starter/camel-netty4-starter/src/main/java/org/apache/camel/component/netty4/springboot/NettyComponentConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-netty4-starter/src/main/java/org/apache/camel/component/netty4/springboot/NettyComponentConfiguration.java
@@ -431,7 +431,6 @@ public class NettyComponentConfiguration
         /**
          * Reference to a class that could be used to return an SSL Handler
          */
-        @NestedConfigurationProperty
         private SslHandler sslHandler;
         /**
          * To configure security using SSLContextParameters
diff --git a/platforms/spring-boot/components-starter/camel-olingo2-starter/src/main/java/org/apache/camel/component/olingo2/springboot/Olingo2ComponentConfiguration.java b/platforms/spring-boot/components-starter/camel-olingo2-starter/src/main/java/org/apache/camel/component/olingo2/springboot/Olingo2ComponentConfiguration.java
index 6a39e7b..556bd3d 100644
--- a/platforms/spring-boot/components-starter/camel-olingo2-starter/src/main/java/org/apache/camel/component/olingo2/springboot/Olingo2ComponentConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-olingo2-starter/src/main/java/org/apache/camel/component/olingo2/springboot/Olingo2ComponentConfiguration.java
@@ -122,7 +122,6 @@ public class Olingo2ComponentConfiguration
         /**
          * HTTP proxy server configuration
          */
-        @NestedConfigurationProperty
         private HttpHost proxy;
         /**
          * To configure security using SSLContextParameters
@@ -135,7 +134,6 @@ public class Olingo2ComponentConfiguration
          * sslContext. Note that a socketTimeout MUST be specified in the
          * builder, otherwise OData requests could block indefinitely
          */
-        @NestedConfigurationProperty
         private HttpAsyncClientBuilder httpAsyncClientBuilder;
         /**
          * Custom HTTP client builder for more complex HTTP client
@@ -143,7 +141,6 @@ public class Olingo2ComponentConfiguration
          * sslContext. Note that a socketTimeout MUST be specified in the
          * builder, otherwise OData requests could block indefinitely
          */
-        @NestedConfigurationProperty
         private HttpClientBuilder httpClientBuilder;
 
         public Olingo2ApiName getApiName() {
diff --git a/platforms/spring-boot/components-starter/camel-olingo4-starter/src/main/java/org/apache/camel/component/olingo4/springboot/Olingo4ComponentConfiguration.java b/platforms/spring-boot/components-starter/camel-olingo4-starter/src/main/java/org/apache/camel/component/olingo4/springboot/Olingo4ComponentConfiguration.java
index 81c18a5..510643c 100644
--- a/platforms/spring-boot/components-starter/camel-olingo4-starter/src/main/java/org/apache/camel/component/olingo4/springboot/Olingo4ComponentConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-olingo4-starter/src/main/java/org/apache/camel/component/olingo4/springboot/Olingo4ComponentConfiguration.java
@@ -122,7 +122,6 @@ public class Olingo4ComponentConfiguration
         /**
          * HTTP proxy server configuration
          */
-        @NestedConfigurationProperty
         private HttpHost proxy;
         /**
          * To configure security using SSLContextParameters
@@ -135,7 +134,6 @@ public class Olingo4ComponentConfiguration
          * sslContext. Note that a socketTimeout MUST be specified in the
          * builder, otherwise OData requests could block indefinitely
          */
-        @NestedConfigurationProperty
         private HttpAsyncClientBuilder httpAsyncClientBuilder;
         /**
          * Custom HTTP client builder for more complex HTTP client
@@ -143,7 +141,6 @@ public class Olingo4ComponentConfiguration
          * sslContext. Note that a socketTimeout MUST be specified in the
          * builder, otherwise OData requests could block indefinitely
          */
-        @NestedConfigurationProperty
         private HttpClientBuilder httpClientBuilder;
 
         public Olingo4ApiName getApiName() {
diff --git a/platforms/spring-boot/components-starter/camel-salesforce-starter/src/main/java/org/apache/camel/component/salesforce/springboot/SalesforceComponentConfiguration.java b/platforms/spring-boot/components-starter/camel-salesforce-starter/src/main/java/org/apache/camel/component/salesforce/springboot/SalesforceComponentConfiguration.java
index c6564f6..f4c882e 100644
--- a/platforms/spring-boot/components-starter/camel-salesforce-starter/src/main/java/org/apache/camel/component/salesforce/springboot/SalesforceComponentConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-salesforce-starter/src/main/java/org/apache/camel/component/salesforce/springboot/SalesforceComponentConfiguration.java
@@ -728,7 +728,6 @@ public class SalesforceComponentConfiguration
          * Custom Jackson ObjectMapper to use when serializing/deserializing
          * Salesforce objects.
          */
-        @NestedConfigurationProperty
         private ObjectMapper objectMapper;
         /**
          * Backoff interval increment for Streaming connection restart attempts
diff --git a/platforms/spring-boot/components-starter/camel-servicenow-starter/src/main/java/org/apache/camel/component/servicenow/springboot/ServiceNowComponentConfiguration.java b/platforms/spring-boot/components-starter/camel-servicenow-starter/src/main/java/org/apache/camel/component/servicenow/springboot/ServiceNowComponentConfiguration.java
index f2ec8fb9f4..6d8ad47 100644
--- a/platforms/spring-boot/components-starter/camel-servicenow-starter/src/main/java/org/apache/camel/component/servicenow/springboot/ServiceNowComponentConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-servicenow-starter/src/main/java/org/apache/camel/component/servicenow/springboot/ServiceNowComponentConfiguration.java
@@ -364,7 +364,6 @@ public class ServiceNowComponentConfiguration
         /**
          * Sets Jackson's ObjectMapper to use for request/reply
          */
-        @NestedConfigurationProperty
         private ObjectMapper mapper;
         /**
          * The ServiceNow release to target, default to Helsinki See
@@ -384,12 +383,10 @@ public class ServiceNowComponentConfiguration
         /**
          * To configure http-client
          */
-        @NestedConfigurationProperty
         private HTTPClientPolicy httpClientPolicy;
         /**
          * To configure proxy authentication
          */
-        @NestedConfigurationProperty
         private ProxyAuthorizationPolicy proxyAuthorizationPolicy;
         /**
          * The proxy host name
diff --git a/tooling/maven/camel-package-maven-plugin/src/main/java/org/apache/camel/maven/packaging/SpringBootAutoConfigurationMojo.java b/tooling/maven/camel-package-maven-plugin/src/main/java/org/apache/camel/maven/packaging/SpringBootAutoConfigurationMojo.java
index 5a63141..fcfc205 100644
--- a/tooling/maven/camel-package-maven-plugin/src/main/java/org/apache/camel/maven/packaging/SpringBootAutoConfigurationMojo.java
+++ b/tooling/maven/camel-package-maven-plugin/src/main/java/org/apache/camel/maven/packaging/SpringBootAutoConfigurationMojo.java
@@ -61,7 +61,6 @@ import org.apache.maven.project.MavenProject;
 import org.jboss.forge.roaster.Roaster;
 import org.jboss.forge.roaster.model.JavaType;
 import org.jboss.forge.roaster.model.Type;
-import org.jboss.forge.roaster.model.source.FieldSource;
 import org.jboss.forge.roaster.model.source.Import;
 import org.jboss.forge.roaster.model.source.Importer;
 import org.jboss.forge.roaster.model.source.JavaClassSource;
@@ -114,9 +113,9 @@ public class SpringBootAutoConfigurationMojo extends AbstractMojo {
     private static final String INNER_TYPE_SUFFIX = "NestedConfiguration";
 
     /**
      * Classes to exclude when adding {@link NestedConfigurationProperty} annotations.
      */
-    private static final Pattern EXCLUDE_INNER_PATTERN = Pattern.compile("^((java\\.)|(javax\\.)|(org\\.springframework\\.context\\.ApplicationContext)|(freemarker\\.template\\.Configuration)).*");
+    private static final Pattern INCLUDE_INNER_PATTERN = Pattern.compile("org\\.apache\\.camel\\..*");
 
     private static final Map<String, String> PRIMITIVEMAP;
 
@@ -747,7 +746,7 @@ public class SpringBootAutoConfigurationMojo extends AbstractMojo {
             PropertySource<JavaClassSource> prop = javaClass.addProperty(type, option.getName());
             if (!type.endsWith(INNER_TYPE_SUFFIX)
                 && type.indexOf('[') == -1
-                && !EXCLUDE_INNER_PATTERN.matcher(type).matches()
+                && INCLUDE_INNER_PATTERN.matcher(type).matches()
                 && Strings.isBlank(option.getEnums())
                 && (javaClassSource == null || (javaClassSource.isClass() && !javaClassSource.isAbstract()))) {
                 // add nested configuration annotation for complex properties
@@ -821,7 +820,7 @@ public class SpringBootAutoConfigurationMojo extends AbstractMojo {
                 }
 
                 // add nested configuration annotation for complex properties
-                if (!EXCLUDE_INNER_PATTERN.matcher(optionType).matches()
+                if (INCLUDE_INNER_PATTERN.matcher(optionType).matches()
                     && !propType.isArray()
                     && !anEnum
                     && optionClass != null
@@ -114,9 +113,9 @@ public class SpringBootAutoConfigurationMojo extends AbstractMojo {
 
     /**
-     * Classes to exclude when adding {@link NestedConfigurationProperty} annotations.
+     * Classes to include when adding {@link NestedConfigurationProperty} annotations.
      */